 \ProvidesFile{macgreek.def}
   [1999/08/27 v0.4b Input encoding file
                        (test version: still liable to change)]
\message{Greek input encoding file for Macintosh (ELOT 823) by Dimitrios Filippou}
\DeclareInputText{128}{\textbullet}
\DeclareInputText{129}{\textbullet}
\DeclareInputText{130}{\textbullet}
\DeclareInputText{131}{\textbullet}
\DeclareInputText{132}{\textbullet}
\DeclareInputText{133}{\textbullet}
\DeclareInputText{134}{\textbullet}
\DeclareInputText{135}{\textbullet}
\DeclareInputText{136}{\textbullet}
\DeclareInputText{137}{\textbullet}
\DeclareInputText{138}{\textbullet}
\DeclareInputText{139}{\textbullet}
\DeclareInputText{140}{\textbullet}
\DeclareInputText{141}{\textbullet}
\DeclareInputText{142}{\textbullet}
\DeclareInputText{143}{\textbullet}
\DeclareInputText{144}{\textbullet}
\DeclareInputText{145}{\textbullet}
\DeclareInputText{146}{\pounds}
\DeclareInputText{147}{\texttrademark}
\DeclareInputText{148}{\textbullet}
\DeclareInputText{149}{\textbullet}
\DeclareInputText{150}{\textbullet}
\DeclareInputText{151}{\textbullet}
\DeclareInputText{152}{\permill}
\DeclareInputText{153}{\textbullet}
\DeclareInputText{154}{\textbullet}
\DeclareInputText{155}{\textbullet}
\DeclareInputText{156}{\textbullet}
\DeclareInputText{157}{\textbullet}
\DeclareInputText{158}{\textbullet}
\DeclareInputText{159}{\textbullet}
\DeclareInputText{160}{\textbullet}
\DeclareInputText{161}{G}
\DeclareInputText{162}{D}
\DeclareInputText{163}{J}
\DeclareInputText{164}{L}
\DeclareInputText{165}{X}
\DeclareInputText{166}{P}
\DeclareInputText{167}{\textbullet}
\DeclareInputText{168}{\textregistered}
\DeclareInputText{169}{\copyright}
\DeclareInputText{170}{S}
\DeclareInputText{171}{\"{I}}
\DeclareInputText{172}{\S}
\DeclareInputMath{173}{\neq}
\DeclareInputMath{174}{^\circ}
\DeclareInputText{175}{;}
\DeclareInputText{176}{A}
\DeclareInputMath{177}{\pm}
\DeclareInputMath{178}{\leq}
\DeclareInputMath{179}{\geq}
\DeclareInputText{180}{\textbullet}
\DeclareInputText{181}{B}
\DeclareInputText{182}{E}
\DeclareInputText{183}{Z}
\DeclareInputText{184}{H}
\DeclareInputText{185}{I}
\DeclareInputText{186}{K}
\DeclareInputText{187}{M}
\DeclareInputText{188}{F}
\DeclareInputText{189}{\"{U}}
\DeclareInputText{190}{Y}
\DeclareInputText{191}{W}
\DeclareInputText{192}{'a}
\DeclareInputText{193}{N}
\DeclareInputMath{194}{\neg}
\DeclareInputText{195}{O}
\DeclareInputText{196}{R}
\DeclareInputMath{197}{\approx}
\DeclareInputText{198}{T}
\DeclareInputText{199}{((}
\DeclareInputText{200}{))}
\DeclareInputText{201}{\dots}
\DeclareInputMath{202}{\textbullet}
\DeclareInputText{203}{U}
\DeclareInputText{204}{Q}
\DeclareInputText{205}{'A}
\DeclareInputText{206}{'E}
\DeclareInputText{207}{\textbullet}
\DeclareInputText{208}{--}
\DeclareInputText{209}{---}
\DeclareInputText{210}{$``$}
\DeclareInputText{211}{$\char '042$}
\DeclareInputText{212}{``}
\DeclareInputText{213}{''}
\DeclareInputMath{214}{\div}
\DeclareInputText{215}{'H}
\DeclareInputText{216}{'I}
\DeclareInputText{217}{'O}
\DeclareInputText{218}{'U}
\DeclareInputText{219}{'e}
\DeclareInputText{220}{'h}
\DeclareInputText{221}{'i}
\DeclareInputText{222}{'o}
\DeclareInputText{223}{'W}
\DeclareInputText{224}{'u}
\DeclareInputText{225}{a}
\DeclareInputText{226}{b}
\DeclareInputText{227}{y}
\DeclareInputText{228}{d}
\DeclareInputText{229}{e}
\DeclareInputText{230}{f}
\DeclareInputText{231}{g}
\DeclareInputText{232}{h}
\DeclareInputText{233}{i}
\DeclareInputText{234}{x}
\DeclareInputText{235}{k}
\DeclareInputText{236}{l}
\DeclareInputText{237}{m}
\DeclareInputText{238}{n}
\DeclareInputText{239}{o}
\DeclareInputText{240}{p}
\DeclareInputText{241}{'w}
\DeclareInputText{242}{r}
\DeclareInputText{243}{s}
\DeclareInputText{244}{t}
\DeclareInputText{245}{j}
\DeclareInputText{246}{w}
\DeclareInputText{247}{c}
\DeclareInputText{248}{q}
\DeclareInputText{249}{u}
\DeclareInputText{250}{z}
\DeclareInputText{251}{"i}
\DeclareInputText{252}{"u}
\DeclareInputText{253}{"'i}
\DeclareInputText{254}{"'u}
\DeclareInputText{255}{\textbullet}
\endinput
%%
%% End of file `macgreek.def'.
